@@ -2,7 +2,7 @@ import jnius_config
 jnius_config.add_classpath("../terrier-project-5.1-jar-with-dependencies.jar")
 from jnius import autoclass, cast
 
-import pytrec_eval
+# import pytrec_eval
 import os, json
 import numpy as np
 import pandas as pd
