@@ -1,6 +1,6 @@
 import pandas as pd
 from jnius import autoclass, cast
-import pytrec_eval
+# import pytrec_eval
 import json
 
 class Utils:
